#!/bin/sh 

# Licensed Materials - Property of IBM
# IBM Cognos Products: PPS
# (C) Copyright IBM Corp. 2009, 2016
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

echo
echo
echo ########## PPStoc11InteropDeploy_Unix.bat ########################### 
echo  
echo -- Isolates all the 10.2.2 PowerPlay Server content
echo -- needed for export to a c11 interop installation.
echo
echo -- Requires:        10.2.2 PPS AppTier 
echo --   AND            10.2.2 PPS Gateway
echo 
echo -- \(Can be executed in series for distributed installs\)
echo 
echo -- Creates subdirectory 'InteropDeployment' beneath 
echo -- the current directory \(should be /bin\). 
echo
echo -- Upon SCRIPT COMPLETE - STATUS OK :
echo -- Take \(or pack\) contents of ./InteropDeployment,
echo -- and copy \(unpack\) directly to c11 *installdir*.
echo -- \(where exist rendition.dat and cmplst.txt!\)
echo
echo -- If any files already exist in Cognos Analytics, 
echo -- OVERWRITE them.
echo
echo -- ./InteropDeployment can then be deleted.
echo
echo ##############################################################
echo
echo
echo Looking for webcontent in:  ../webcontent   ...
if [ -e "../webcontent" ]
then
	echo ... located webcontent
else
	echo ERROR: Could not locate any existing ../webcontent
	echo Export Failed! Aborting.
	exit -100
fi

echo      ... creating InteropDeployment target directory
echo
mkdir -p ./InteropDeployment/webapps/p2pd/WEB-INF/fragments/applications/cogadmin/fragments
if [ -e "./InteropDeployment" ]
then
	echo ... found InteropDeployment target directory
else
	echo ERROR: Could not create InteropDeployment subdirectory
	echo Export Failed! Aborting.
	exit -101
fi

mkdir -p ./InteropDeployment/webapps/p2pd/WEB-INF/fragments/applications/cogadmin/pages

echo     ... copying content
echo
echo ... acquiring cogadmin fragments
cp ../webapps/p2pd/WEB-INF/fragments/applications/cogadmin/fragments/ppesAdmin* ./InteropDeployment/webapps/p2pd/WEB-INF/fragments/applications/cogadmin/fragments
cp ../webapps/p2pd/WEB-INF/fragments/applications/cogadmin/pages/ppesAdmin* ./InteropDeployment/webapps/p2pd/WEB-INF/fragments/applications/cogadmin/pages

echo ... acquiring skins
mkdir -p ./InteropDeployment/webcontent/bi/skins/business
mkdir ./InteropDeployment/webcontent/bi/skins/classic
mkdir ./InteropDeployment/webcontent/bi/skins/contemporary
mkdir ./InteropDeployment/webcontent/bi/skins/corporate
mkdir ./InteropDeployment/webcontent/bi/skins/modern
mkdir ./InteropDeployment/webcontent/bi/skins/presentation
mkdir ./InteropDeployment/webcontent/bi/skins/series7
cp -r ../webcontent/skins/business/ppwb ./InteropDeployment/webcontent/bi/skins/business
cp -r ../webcontent/skins/classic/ppwb ./InteropDeployment/webcontent/bi/skins/classic
cp -r ../webcontent/skins/contemporary/ppwb ./InteropDeployment/webcontent/bi/skins/contemporary
cp -r ../webcontent/skins/corporate/ppwb ./InteropDeployment/webcontent/bi/skins/corporate
cp -r ../webcontent/skins/modern/ppwb ./InteropDeployment/webcontent/bi/skins/modern
cp -r ../webcontent/skins/presentation/ppwb ./InteropDeployment/webcontent/bi/skins/presentation
cp -r ../webcontent/skins/series7/ppwb ./InteropDeployment/webcontent/bi/skins/series7
cp -r ./InteropDeployment/webcontent/bi/skins ./InteropDeployment/webcontent

echo ... acquiring ppwb webcontent
cp -r ../webcontent/ppwb ./InteropDeployment/webcontent
cp -r ../webcontent/ppwb ./InteropDeployment/webcontent/bi
mkdir ./InteropDeployment/webcontent/ps
cp -r ../webcontent/ps/powerplaystudio ./InteropDeployment/webcontent/ps
mkdir ./InteropDeployment/msgsdk
cp ../msgsdk/ppesAdminStrings* ./InteropDeployment/msgsdk
mkdir ./InteropDeployment/webcontent/fragments
cp -r ../webcontent/fragments/ppesAdmin ./InteropDeployment/webcontent/fragments

echo ... acquiring eclipse plugins
mkdir ./InteropDeployment/eclipse
cp -r ../eclipse/plugins ./InteropDeployment/eclipse

mkdir ./InteropDeployment/vers
cp ../vers/pps-* ./InteropDeployment/vers
cp ../vers/ppsadmin-* ./InteropDeployment/vers


echo
echo SCRIPT COMPLETE - STATUS OK
echo

